@@ -54,7 +54,7 @@ GtkWidget* org_gnome_exchange_settings(EPlugin *epl, EConfigHookItemFactoryData
 GtkWidget *org_gnome_exchange_owa_url(EPlugin *epl, EConfigHookItemFactoryData *data);
 gboolean org_gnome_exchange_check_options(EPlugin *epl, EConfigHookPageCheckData *data);
 GtkWidget *org_gnome_exchange_auth_section (EPlugin *epl, EConfigHookItemFactoryData *data);
-void org_gnome_exchange_commit (EPlugin *epl, EConfigHookItemFactoryData *data);
+void org_gnome_exchange_commit (EPlugin *epl, EMConfigTargetAccount *target_account);
 GtkWidget* org_gnome_exchange_show_folder_size_factory (EPlugin *epl, EConfigHookItemFactoryData *data);
 
 CamelServiceAuthType camel_exchange_ntlm_authtype = {
@@ -85,7 +85,7 @@ typedef struct {
 	GtkWidget *text_view;
 }OOFData;
 
-static OOFData *oof_data;
+static OOFData *oof_data = NULL;
 
 static void
 update_state (GtkTextBuffer *buffer, gpointer data)
@@ -308,6 +308,7 @@ org_gnome_exchange_settings(EPlugin *epl, EConfigHookItemFactoryData *data)
 	gtk_text_buffer_get_bounds (buffer, &start, &end);
 	oof_message = gtk_text_buffer_get_text (buffer, &start, &end, FALSE);
 	if (oof_message && *oof_message) {
+		g_free (oof_data->message);
 		/* Will this ever happen? */
 		oof_data->message = oof_message;
 	}
@@ -357,7 +358,7 @@ org_gnome_exchange_settings(EPlugin *epl, EConfigHookItemFactoryData *data)
 	gtk_box_pack_start (GTK_BOX (vbox_auth), GTK_WIDGET (tbl_auth), FALSE, FALSE, 0);
 
 	/* Miscelleneous settings */
-	frm_misc = (GtkFrame*) g_object_new (GTK_TYPE_FRAME, "label", _("Miscelleneous"), NULL);
+	frm_misc = (GtkFrame*) g_object_new (GTK_TYPE_FRAME, "label", _("Miscellaneous"), NULL);
 	gtk_box_pack_start (GTK_BOX (vbox_settings), GTK_WIDGET (frm_misc), FALSE, FALSE, 0);
 
 	vbox_misc = (GtkVBox*) g_object_new (GTK_TYPE_VBOX, "homogeneous", FALSE, "spacing", 6, NULL);
@@ -544,9 +545,9 @@ owa_authenticate_user(GtkWidget *button, EConfig *config)
 static void
 owa_editor_entry_changed(GtkWidget *entry, EConfig *config)
 {
-	const gchar *uri, *ssl = NULL;
+	const gchar *ssl = NULL;
 	CamelURL *url, *owaurl = NULL;
-	gchar *url_string;
+	gchar *url_string, *uri;
 	EMConfigTargetAccount *target = (EMConfigTargetAccount *)config->target;
 	GtkWidget *button = g_object_get_data((GObject *)entry, "authenticate-button");
 	gint active = FALSE;
@@ -557,7 +558,10 @@ owa_editor_entry_changed(GtkWidget *entry, EConfig *config)
 	if (target_url && target_url[0] != '\0')
 		url = camel_url_new(target_url, NULL);
 	else url = NULL;
-	uri = gtk_entry_get_text((GtkEntry *)entry);
+	uri = g_strdup (gtk_entry_get_text((GtkEntry *)entry));
+
+	g_strstrip (uri);
+
 	if (uri && uri[0]) {
 		camel_url_set_param(url, "owa_url", uri);
 		owaurl = camel_url_new(uri, NULL);
@@ -580,6 +584,7 @@ owa_editor_entry_changed(GtkWidget *entry, EConfig *config)
 	e_account_set_string(target->account, E_ACCOUNT_SOURCE_URL, url_string);
 	g_free(url_string);
 	camel_url_free (url);
+	g_free (uri);
 }
 
 static void
@@ -613,13 +618,17 @@ static void
 mailbox_editor_entry_changed (GtkWidget *entry, EConfig *config)
 {
 	EMConfigTargetAccount *target;
-	const gchar *mailbox;
+	gchar *mailbox;
 
 	target = (EMConfigTargetAccount *)config->target;
-	mailbox = gtk_entry_get_text (GTK_ENTRY (entry));
+	mailbox = g_strdup (gtk_entry_get_text (GTK_ENTRY (entry)));
+
+	g_strstrip (mailbox);
 
 	update_mailbox_param_in_url (target->account, E_ACCOUNT_SOURCE_URL, mailbox);
 	update_mailbox_param_in_url (target->account, E_ACCOUNT_TRANSPORT_URL, mailbox);
+
+	g_free (mailbox);
 }
 
 static void
@@ -775,7 +784,7 @@ org_gnome_exchange_owa_url(EPlugin *epl, EConfigHookItemFactoryData *data)
 
 	row++;
 	want_mailbox_check = gtk_check_button_new_with_mnemonic (
-		_("Mailbox name is _different than user name"));
+		_("Mailbox name is _different from user name"));
 	gtk_widget_show (want_mailbox_check);
 	gtk_table_attach (GTK_TABLE (data->parent), want_mailbox_check, 1, 2, row, row+1, GTK_FILL, GTK_FILL, 0, 0);
 	if (!username || !*username || !mailbox_name || !*mailbox_name ||
@@ -854,6 +863,8 @@ set_oof_info (GtkWidget *parent)
 {
 	ExchangeAccount *account;
 
+	g_return_if_fail (oof_data != NULL);
+
 	account = exchange_operations_get_exchange_account ();
 
 	if (account && !exchange_oof_set (account, oof_data->state, oof_data->message)) {
@@ -865,21 +876,24 @@ set_oof_info (GtkWidget *parent)
 static void
 destroy_oof_data (void)
 {
-	if (oof_data->message)
+	if (oof_data && oof_data->message) {
 		g_free (oof_data->message);
-	if (oof_data)
+		oof_data->message = NULL;
+	}
+
+	if (oof_data) {
 		g_free (oof_data);
+		oof_data = NULL;
+	}
 }
 
 void
-org_gnome_exchange_commit (EPlugin *epl, EConfigHookItemFactoryData *data)
+org_gnome_exchange_commit (EPlugin *epl, EMConfigTargetAccount *target_account)
 {
-	EMConfigTargetAccount *target_account;
 	const gchar *source_url;
 	CamelURL *url;
 	gint offline_status;
 
-	target_account = (EMConfigTargetAccount *)data->config->target;
 	source_url = e_account_get_string (target_account->account,  E_ACCOUNT_SOURCE_URL);
 	if (source_url && source_url[0] != '\0')
 		url = camel_url_new (source_url, NULL);
@@ -892,10 +906,6 @@ org_gnome_exchange_commit (EPlugin *epl, EConfigHookItemFactoryData *data)
 
 		return;
 	}
-	if (data->old) {
-		camel_url_free(url);
-		return;
-	}
 
 	camel_url_free (url);
 
@@ -907,7 +917,7 @@ org_gnome_exchange_commit (EPlugin *epl, EConfigHookItemFactoryData *data)
 	}
 
 	/* Set oof data in exchange account */
-	set_oof_info (data->config->target->widget);
+	set_oof_info (target_account->target.widget);
 	destroy_oof_data ();
 	return;
 }
